==> certora_cli_alpha_master-20240130.14.38.129030-py3-none-macosx_10_9_universal2.whl: certora_cli/Mutate/mutateConstants.py <==

from pathlib import Path

VERIFICATION_PROGRESS = "verificationProgress"
RULENAME = "RULENAME"
TIMEOUT = "TIMEOUT"
UNKNOWN = "UNKNOWN"
SANITY_FAIL = "SANITY_FAIL"
RULES = "rules"
JOB_STATUS = "jobStatus"
JOB_DATA = "jobData"
PROGRESS = "progress"
ZIPOUTPUT = "zipOutput"
GENERALSTATE = "generalState"
PARAMS = "params"
OUTPUT = "output"
INPUTS = "inputs"
TARNAME = "TarName"
NAME = "name"
ID = "id"
COLLECT_SIGNED_URL = "preSignedUrl"
DIFF = "diff"
DESCRIPTION = "description"
ORIGINAL = "original"
MUTANTS = "mutants"
GAMBIT_MUTANT = "gambit_mutant"
GAMBIT_OUT = "gambit_out"
GAMBIT = "gambit"
GAMBIT_OUTDIR = "outdir"
FILENAME = "filename"
FILES = "files"
LINK = "link"
RULE_REPORT_LINK = "rule_report_link"
CERTORA_KEY = "certoraKey"
ANONYMOUS_KEY = "anonymousKey"
PRE_SIGNED_URL = "preSignedUrl"
STATUS = "status"
CHILDREN = "children"
NUM_MUTANTS = "num_mutants"
MANUAL_MUTANTS = "manual_mutants"
MSG = "msg"
TMP_GAMBIT = "tmp_gambit.conf"
SOLC = "solc"
PACKAGES = "packages"
SOLC_REMAPPINGS = "solc_remappings"
SOLC_ALLOW_PATH = "solc_allow_path"  # why
SOLC_ALLOW_PATHS = "solc_allow_paths"  # just, why
ZIP_PATH = "zip_output_certora_mutate.tar.gz"
CERTORA_MUTATE_SOURCES = ".certora_mutate_sources"
APPLIED_MUTANTS_DIR_NAME = "applied_mutants"
SERVER = "server"
STAGING = "staging"
PRODUCTION = "production"
DEV = "vaas-dev"
CONF = "conf"
ORIG_RUN_PROVER_CONF = "cvt_conf_for_certoraMutate.conf"
PROVER_DOTCOM = "prover.certora.com"
STAGING_DOTCOM = "vaas-stg.certora.com"
DEV_DOTCOM = "vaas-dev.certora.com"
MUTATION_TEST_REPORT_PRODUCTION = "mutation-testing.certora.com"
MUTATION_TEST_REPORT_STAGING = "mutation-testing-beta.certora.com"
MUTATION_TEST_REPORT_DEV = "mutation-testing-dev.certora.com"
OUTPUTJSON = "output.json"
REPORTS = "Reports"
DEFAULT_DUMP_FAILED_COLLECTS = Path("collection_failures.txt")
DEFAULT_COLLECT_FILE = Path("collect.json")
DEFAULT_POLL_TIMEOUT_IN_SECS = 30
DEFAULT_REQUEST_TIMEOUT_IN_SECS = 10
DEFAULT_MAX_TIMEOUT_ATTEMPTS_COUNT = 3
# Sets a file that will store the object sent to mutation testing UI (useful for testing)
DEFAULT_UI_OUT = Path("results.json")
SPLIT_STATS_DATA = "splitStatsdata.json"

==> certora_cli_alpha_master-20240208.19.53.150981-py3-none-macosx_10_9_universal2.whl: certora_cli/Mutate/mutateConstants.py <==

from pathlib import Path

VERIFICATION_PROGRESS = "verificationProgress"
RULENAME = "RULENAME"
TIMEOUT = "TIMEOUT"
UNKNOWN = "UNKNOWN"
SANITY_FAIL = "SANITY_FAIL"
RULES = "rules"
JOB_STATUS = "jobStatus"
JOB_DATA = "jobData"
PROGRESS = "progress"
ZIPOUTPUT = "zipOutput"
GENERALSTATE = "generalState"
PARAMS = "params"
OUTPUT = "output"
INPUTS = "inputs"
TARNAME = "TarName"
NAME = "name"
ID = "id"
COLLECT_SIGNED_URL = "preSignedUrl"
DIFF = "diff"
DESCRIPTION = "description"
ORIGINAL = "original"
MUTANTS = "mutants"
GAMBIT_MUTANT = "gambit_mutant"
GAMBIT_OUT = "gambit_out"
GAMBIT = "gambit"
GAMBIT_OUTDIR = "outdir"
FILENAME = "filename"
FILES = "files"
LINK = "link"
RULE_REPORT_LINK = "rule_report_link"
CERTORA_KEY = "certoraKey"
ANONYMOUS_KEY = "anonymousKey"
PRE_SIGNED_URL = "preSignedUrl"
STATUS = "status"
CHILDREN = "children"
NUM_MUTANTS = "num_mutants"
MANUAL_MUTANTS = "manual_mutants"
MSG = "msg"
TMP_GAMBIT = "tmp_gambit.gconf"
SOLC = "solc"
PACKAGES = "packages"
SOLC_REMAPPINGS = "solc_remappings"
SOLC_ALLOW_PATH = "solc_allow_path"  # why
SOLC_ALLOW_PATHS = "solc_allow_paths"  # just, why
ZIP_PATH = "zip_output_certora_mutate.tar.gz"
CERTORA_MUTATE_SOURCES = ".certora_mutate_sources"
APPLIED_MUTANTS_DIR_NAME = "applied_mutants"
SERVER = "server"
STAGING = "staging"
PRODUCTION = "production"
DEV = "vaas-dev"
CONF = "conf"
ORIG_RUN_PROVER_CONF = "cvt_conf_for_certoraMutate.conf"
PROVER_DOTCOM = "prover.certora.com"
STAGING_DOTCOM = "vaas-stg.certora.com"
DEV_DOTCOM = "vaas-dev.certora.com"
MUTATION_DASHBOARD = "https://prover.certora.com/mutations"
MUTATION_TEST_REPORT_PRODUCTION = "mutation-testing.certora.com"
MUTATION_TEST_REPORT_STAGING = "mutation-testing-beta.certora.com"
MUTATION_TEST_REPORT_DEV = "mutation-testing-dev.certora.com"
OUTPUTJSON = "output.json"
REPORTS = "Reports"
DEFAULT_DUMP_FAILED_COLLECTS = Path("collection_failures.txt")
DEFAULT_COLLECT_FILE = Path("collect.json")
DEFAULT_POLL_TIMEOUT_IN_SECS = 30
DEFAULT_REQUEST_TIMEOUT_IN_SECS = 10
DEFAULT_MAX_TIMEOUT_ATTEMPTS_COUNT = 3
# Sets a file that will store the object sent to mutation testing UI (useful for testing)
DEFAULT_UI_OUT = Path("results.json")
SPLIT_STATS_DATA = "splitStatsdata.json"
DEFAULT_CSV_JOB_STATUS = "TIMEOUT/UNKNOWN"
